@@ -294,7 +294,7 @@ class Resource(object):
     
     def finish_request(self, req, resp):
         """
-        This function, if exported, is called just before the final 
+        This function, if defined, is called just before the final 
         response is constructed and sent. The Result is ignored, so
         any effect of this function must be by returning a modified 
         request.
@@ -431,7 +431,7 @@ class Resource(object):
         If POST requests should be treated as a request to put content
         into a (potentially new) resource as opposed to being a generic 
         submission for processing, then this function should return true. 
-        If it does return true, then create_path will be called and the 
+        If it does return true, then created_location will be called and the 
         rest of the request will be treated much like a PUT to the Path 
         entry returned by that call.
 
@@ -587,7 +587,6 @@ class Resource(object):
         try:
             state = b13
             while not isinstance(state, int):
-                print state
                 if state(self, req, resp):
                     state = TRANSITIONS[state][0]
                 else:
@@ -621,8 +620,8 @@ class Resource(object):
 
         if resp.location is not None:
             resp['Location'] = resp.location
-
-        print resp.content
+         
+        self.finish_request(req, resp)
         return resp
 
     def __call__(self, request, *args, **kwargs):
